import { Command, flags } from '@oclif/command';
import { IOptionFlag } from '@oclif/command/lib/flags';
import { MnemonicPassPhrase } from 'symbol-hd-wallets';
import { Account, NetworkType, PublicAccount } from 'symbol-sdk';
import { PrivateKeySecurityMode } from '../model';
import { KeyName, Preset, RewardProgram } from '../service';
export declare const assemblies: Record<Preset, {
    value: string;
    description: string;
}[]>;
export declare enum Network {
    mainnet = "mainnet",
    testnet = "testnet",
    privateNetwork = "privateNetwork"
}
export declare enum ImportType {
    OPTIN_PAPER_WALLET = "optinPaperWallet",
    SYMBOL_PAPER_WALLET = "symbolPaperWallet",
    PRIVATE_KEYS = "privateKeys"
}
export interface DerivedAccount {
    optinMode: boolean;
    networkType: NetworkType;
    account: Account;
    accountIndex: number;
    changeIndex: number;
    mnemonicPassPhrase: MnemonicPassPhrase;
}
export interface BootstrapPresetContent {
    preset?: string;
    assembly?: string;
    privateKeySecurityMode?: PrivateKeySecurityMode;
    nodes: {
        voting: boolean;
        host?: string | undefined;
        friendlyName?: string;
        rewardProgram?: RewardProgram;
        mainPrivateKey: string;
        transportPrivateKey: string;
        remotePrivateKey: string;
        vrfPrivateKey: string;
        votingPrivateKey?: string;
    }[];
}
export interface ProvidedAccounts {
    seeded: boolean;
    main: Account;
    remote: Account;
    vrf: Account;
    voting?: Account;
    transport: Account;
}
export declare const networkToPreset: Record<Network, Preset>;
export default class Wizard extends Command {
    static description: string;
    static examples: string[];
    static flags: {
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        target: flags.IOptionFlag<string>;
        password: flags.IOptionFlag<string | undefined>;
        noPassword: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
        network: flags.IOptionFlag<Network | undefined>;
    };
    run(): Promise<void>;
    static logAccount<T extends Account | PublicAccount | undefined>(account: T, keyName: KeyName, showPrivateKeys: boolean): T;
    private resolveAccounts;
    private resolveAllAccount;
    resolveAccount(networkType: NetworkType, derivedAccount: DerivedAccount | undefined, keyName: KeyName, changeIndex: number): Promise<Account>;
    static resolveAccount(networkType: NetworkType, keyName: KeyName): Promise<Account | undefined>;
    static resolveNetwork(providedNetwork: Network | undefined): Promise<Network>;
    static resolvePrivateKeySecurityMode(): Promise<PrivateKeySecurityMode>;
    static resolveAssembly(preset: Preset): Promise<string>;
    static resolveImportMode(): Promise<ImportType>;
    private static isVoting;
    static getNetworkIdFlag(): IOptionFlag<Network | undefined>;
    static isValidPhrase(input: string): boolean | string;
    resolveDerivedAccount(networkType: NetworkType, optinMode: boolean): Promise<DerivedAccount | undefined>;
    private findDerivedAccounts;
    static toAccountFromMnemonicPhrase(mnemonicPassPhrase: MnemonicPassPhrase, networkType: NetworkType, optinMode: boolean, accountIndex: number, changeIndex: number): Account;
    static resolveRewardProgram(): Promise<RewardProgram | undefined>;
    static resolveHost(message: string, required: boolean): Promise<string>;
    static isValidHost(input: string): boolean | string;
    static isValidFriendlyName(input: string): boolean | string;
    static resolveFriendlyName(defaultFriendlyName: string): Promise<string>;
}
